@@ -31,6 +31,7 @@ sub defaults {
             quote_identifiers    => 1,
             thsd_sep             => ',',
             show_table_name      => 0,
+            dots                 => 0,
             base_indent          => 1,
             file_find_warnings   => 0,
         },
@@ -95,6 +96,7 @@ sub defaults {
             empty_to_null_plain   => 1,
             empty_to_null_copy    => 1,
             empty_to_null_file    => 0,
+            data_source           => 3,
             show_hidden_files     => 0,
             file_filter           => '',
         },
